Avendesora Collaborative Password Utility
=========================================

Introduction
------------
Avendesora is currently early in development. To use it, create symbolic links 
from ~/.config/avendesora/config and ~/.config/avendesora/accounts to the files 
with the same names in ./etc.

Install with::

    pip install --user avendesora

.. image:: https://travis-ci.org/KenKundert/avendesora.svg?branch=master
    :target: https://travis-ci.org/KenKundert/avendesora
